[![](https://codecov.io/gh/nickderobertis/pypi-sphinx-flexlate-example/branch/main/graph/badge.svg)](https://codecov.io/gh/nickderobertis/pypi-sphinx-flexlate-example)
[![PyPI](https://img.shields.io/pypi/v/pypi-sphinx-flexlate-example)](https://pypi.org/project/pypi-sphinx-flexlate-example/)
![PyPI - License](https://img.shields.io/pypi/l/pypi-sphinx-flexlate-example)
[![Documentation](https://img.shields.io/badge/documentation-pass-green)](https://nickderobertis.github.io/pypi-sphinx-flexlate-example/)
[![Github Repo](https://img.shields.io/badge/repo-github-informational)](https://github.com/nickderobertis/pypi-sphinx-flexlate-example/)


#  pypi-sphinx-flexlate-example

## Overview

Example output for https://github.com/nickderobertis/copier-pypi-sphinx-flexlate

## Getting Started

Install `pypi-sphinx-flexlate-example`:

```
pip install pypi-sphinx-flexlate-example
```

A simple example:

```python
import pypi_sphinx_flexlate_example

# Do something with pypi_sphinx_flexlate_example
```

See a
[more in-depth tutorial here.](
https://nickderobertis.github.io/pypi-sphinx-flexlate-example/tutorial.html
)

## Development Status

This project is currently in early-stage development. There may be
breaking changes often. While the major version is 0, minor version
upgrades will often have breaking changes.

## Author

Created by Nick DeRobertis. MIT License.

## Links

See the
[documentation here.](
https://nickderobertis.github.io/pypi-sphinx-flexlate-example/
)
